From 6494a503f4ce11634cfd42d562011541b1e4ebf9 Mon Sep 17 00:00:00 2001
From: 嘉渊 <wangjiaming.wjm@alibaba-inc.com>
Date: 星期二, 18 七月 2023 14:55:24 +0800
Subject: [PATCH] update
---
egs/callhome/eend_ola/run.sh | 25 ++++++++++++++++++++-----
1 files changed, 20 insertions(+), 5 deletions(-)
diff --git a/egs/callhome/eend_ola/run.sh b/egs/callhome/eend_ola/run.sh
index 8936137..f5afd73 100644
--- a/egs/callhome/eend_ola/run.sh
+++ b/egs/callhome/eend_ola/run.sh
@@ -27,8 +27,8 @@
exp_dir="."
input_size=345
-stage=1
-stop_stage=4
+stage=-1
+stop_stage=-1
# exp tag
tag="exp_fix"
@@ -50,11 +50,26 @@
simu_allspkr_chunk2000_model_dir="baseline_$(basename "${simu_allspkr_chunk2000_diar_config}" .yaml)_${tag}"
callhome_model_dir="baseline_$(basename "${callhome_diar_config}" .yaml)_${tag}"
-# Prepare data for training and inference
-if [ ${stage} -le 0 ] && [ ${stop_stage} -ge 0 ]; then
- echo "stage 0: Prepare data for training and inference"
+# simulate mixture data for training and inference
+if [ ${stage} -le -1 ] && [ ${stop_stage} -ge -1 ]; then
+ echo "stage 0: Simulate mixture data for training and inference"
+ echo "The detail can be found in https://github.com/hitachi-speech/EEND"
+ ehco "Before running this step, you should download and compile kaldi and set KALDI_ROOT in this script and path.sh"
+ echo "This stage may take a long time, please waiting..."
+ KALDI_ROOT=
+ ln -s $KALDI_ROOT/egs/wsj/s5/steps steps
+ ln -s $KALDI_ROOT/egs/wsj/s5/utils utils
+ . local/run_prepare_shared_eda.sh
fi
+## Prepare data for training and inference
+#if [ ${stage} -le 0 ] && [ ${stop_stage} -ge 0 ]; then
+# echo "stage 0: Prepare data for training and inference"
+# echo "The detail can be found in https://github.com/hitachi-speech/EEND"
+# . ./local/
+#fi
+#
+
# Training on simulated two-speaker data
world_size=$gpu_num
simu_2spkr_ave_id=avg${simu_average_2spkr_start}-${simu_average_2spkr_end}
--
Gitblit v1.9.1